@@ -219,17 +219,19 @@ let commands : commands = [
   "slave",        make_command "VERSION"                       Slave.handle      @@ common_options;
 ]
 
+let pp_commands parents fmt commands =
+  commands |> List.iter (fun (command, info) ->
+    match info with
+    | Command info when (Command_tree.help info = None) -> ()
+    | _ -> Format.fprintf fmt "0install%s %s@," parents command
+  )
+
 let show_group_help config parents group =
-  let print fmt = Support.Utils.print config.system fmt in
   let top_options = show_version_options @ common_options in
-  Common_options.show_help config.system top_options "COMMAND [OPTIONS]" (fun () ->
+  Common_options.show_help config.system top_options "COMMAND [OPTIONS]" (fun fmt ->
     let parents = String.concat "" (List.map ((^) " ") parents) in
-    print "\nTry --help with one of these:\n";
-    ListLabels.iter group ~f:(fun (command, info) ->
-      match info with
-      | Command info when (Command_tree.help info = None) -> ()
-      | _ -> print "0install%s %s" parents command;
-    );
+    Format.fprintf fmt "Try --help with one of these:@\n@\n@[<v2>  %a@]@."
+      (pp_commands parents) group
   )
 
 let handle_no_command options flags args =
@@ -248,7 +250,8 @@ let make_tools config =
   let gui = ref Maybe in
   let pool = ref None in
   let ui = lazy (Zeroinstall.Default_ui.make_ui config !gui) in
-  let distro = lazy (Zeroinstall.Distro_impls.get_host_distribution config) in
+  let packagekit = lazy (Zeroinstall.Packagekit.make (Support.Locale.LangMap.choose config.langs |> fst)) in
+  let distro = lazy (Zeroinstall.Distro_impls.get_host_distribution ~packagekit config) in
   let trust_db = lazy (new Zeroinstall.Trust.trust_db config) in
   let download_pool = lazy (let p = Zeroinstall.Downloader.make_pool ~max_downloads_per_site:2 in pool := Some p; p) in
   let make_fetcher = lazy (Zeroinstall.Fetch.make config (Lazy.force trust_db) (Lazy.force distro) (Lazy.force download_pool)) in
