@@ -176,9 +176,8 @@ let build_tree_view config ~parent ~packing ~icon_cache ~show_component ~report_
     if have_source then (
       let compile ~autocompile () =
         Gtk_utils.async ~parent (fun () ->
-          lwt () = Gui.compile config watcher#feed_provider iface ~autocompile in
-          recalculate ~force:false;
-          Lwt.return ()
+          Gui.compile config watcher#feed_provider iface ~autocompile >|= fun () ->
+          recalculate ~force:false
         ) in
       let compile_menu = GMenu.menu () in
       compile_item#set_submenu compile_menu;
@@ -232,8 +231,8 @@ let build_tree_view config ~parent ~packing ~icon_cache ~show_component ~report_
         | None ->
             let name =
               match master_feed with
-              | `remote_feed url -> U.string_tail url (String.rindex url '/' + 1)
-              | `local_feed path -> path in
+              | `Remote_feed url -> U.string_tail url (String.rindex url '/' + 1)
+              | `Local_feed path -> path in
             (name, "", []) in
 
       let user_feeds = (feed_provider#get_iface_config uri).FC.extra_feeds in
