@@ -12,20 +12,20 @@ let () = ignore on_windows
  * If called while something is queued, drop the queued item and queue the new one instead.
  * This is useful to ensure that updates to the GUI are displayed, but don't interfere with each other. *)
 let make_limiter ~parent =
-  let state = ref `idle in
+  let state = ref `Idle in
   let rec run fn =
     match !state with
-    | `running | `running_with_queued _  -> state := `running_with_queued fn
-    | `idle ->
-        state := `running;
+    | `Running | `Running_with_queued _  -> state := `Running_with_queued fn
+    | `Idle ->
+        state := `Running;
         Gtk_utils.async ~parent (fun () ->
-          try_lwt
-            fn ()
-          finally
-            begin match !state with
-            | `idle -> assert false
-            | `running -> state := `idle
-            | `running_with_queued fn -> state := `idle; run fn end;
-            Lwt.return ()
+          Lwt.finalize fn
+            (fun () ->
+              begin match !state with
+              | `Idle -> assert false
+              | `Running -> state := `Idle
+              | `Running_with_queued fn -> state := `Idle; run fn end;
+              Lwt.return ()
+            )
         ) in
   run
