@@ -46,8 +46,8 @@ module Platform =
 
 (** Convenient way to create a new [Safe_exception] with no initial context. *)
 let raise_safe fmt =
-  let do_raise msg = raise @@ Safe_exception (msg, ref []) in
-  Printf.ksprintf do_raise fmt
+  fmt |> Logging.kasprintf @@ fun msg ->
+  raise (Safe_exception (msg, ref []))
 
 module StringMap = struct
   include Map.Make(String)
@@ -64,6 +64,7 @@ class type system =
   object
     method argv : string array
     method print_string : string -> unit
+    method std_formatter : Format.formatter
     method time : float
     method isatty : Unix.file_descr -> bool
 
@@ -89,7 +90,7 @@ class type system =
     method symlink : target:filepath -> newlink:filepath -> unit
     method readlink : filepath -> filepath option
 
-    method exec : ?search_path:bool -> ?env:string array -> string list -> 'a
+    method exec : 'a. ?search_path:bool -> ?env:string array -> string list -> 'a
     method spawn_detach : ?search_path:bool -> ?env:string array -> string list -> unit
     method create_process : ?env:string array -> string list -> Unix.file_descr -> Unix.file_descr -> Unix.file_descr -> int
     (** [reap_child ?kill_first:signal child_pid] calls [waitpid] to collect the child.
@@ -137,10 +138,33 @@ let reraise_with_context ex fmt =
     raise ex
   in Printf.ksprintf do_raise fmt
 
+(** [with_error_info note f] is [f ()], except that if it raises [Safe_exception] then
+    we call [note writer] and add whatever is passed to writer to the context. *)
+let with_error_info note f =
+  Lwt.catch f
+    (function
+      | Safe_exception (_, old_contexts) as ex ->
+        let writer fmt =
+          fmt |> Logging.kasprintf (fun context -> old_contexts := context :: !old_contexts) in
+        note writer;
+        raise ex
+      | ex -> Lwt.fail ex
+    )
+
 let log_debug = Logging.log_debug
 let log_info = Logging.log_info
 let log_warning = Logging.log_warning
 
+(** [with_errors_logged note f] is [f ()], except that if it raises any exception, the
+    exception is logged at warning level with the message provided by [note]. The exception
+    is not re-raised. *)
+let with_errors_logged note f =
+  Lwt.catch f
+    (fun ex ->
+       note (log_warning ~ex);
+       Lwt.return ()
+    )
+
 (** [default d opt] unwraps option [opt], returning [d] if it was [None]. *)
 let default d = function
   | None -> d
