@@ -7,6 +7,7 @@ open Common
 module type UnixType = module type of Unix
 
 (** OCaml's Unix.utimes is broken (doesn't work for times in the interval [0,1), so use our own C function. *)
+(* Note: fixed in OCaml 4.03 *)
 external set_mtime : string -> float -> unit = "ocaml_set_mtime"
 external uname : unit -> Platform.t = "ocaml_0install_uname"
 
@@ -78,6 +79,7 @@ module RealSystem (U : UnixType) =
         method argv = Sys.argv
         method isatty = Unix.isatty
         method print_string = print_string
+        method std_formatter = Format.std_formatter
         method time = Unix.time ()
         method mkdir = Unix.mkdir
         method file_exists = Sys.file_exists
