@@ -349,9 +349,8 @@ let slice ~start ?stop lst =
             | (x::xs) -> x :: take xs (i - 1)
       in take from_start (stop - start)
 
-let print (system:system) =
-  let do_print msg = system#print_string (msg ^ "\n") in
-  Printf.ksprintf do_print
+let print (system:system) fmt =
+  Logging.kasprintf system#print_string (fmt ^^ "@.")
 
 let realpath (system:system) path =
   let (+/) = Filename.concat in   (* Faster version, since we know the path is relative *)
