@@ -8,15 +8,15 @@ open Support.Common
 module Config = Zeroinstall.Config
 module U = Support.Utils
 
-let orig_packagekit = !Zeroinstall.Packagekit.packagekit
-
-let () =
+let reset_env () =
   (* Make oUnit 2 happy: we need to be able to reset these to their initial values after each test. *)
-  Unix.putenv "ZEROINSTALL_PORTABLE_BASE" "/UNUSED";
+  Unix.putenv "ZEROINSTALL_PORTABLE_BASE" "/PORTABLE_UNUSED";
   Unix.putenv "DISPLAY" "";
-  Unix.putenv "DBUS_SESSION_BUS_ADDRESS" "UNUSED";
-  Unix.putenv "DBUS_SYSTEM_BUS_ADDRESS" "UNUSED";
-  Unix.putenv "GNUPGHOME" "/UNUSED"
+  Unix.putenv "DBUS_SESSION_BUS_ADDRESS" "DBUS_SESSION_UNUSED";
+  Unix.putenv "DBUS_SYSTEM_BUS_ADDRESS" "DBUS_SYSTEM_UNUSED";
+  Unix.putenv "GNUPGHOME" "/GPG_UNUSED"
+
+let () = reset_env ()
 
 (* For temporary directory names *)
 let () = Random.self_init ()
@@ -86,24 +86,30 @@ let capture_stdout_lwt ?(include_stderr=false) fn =
   let open Unix in
   let old_stdout = dup Unix.stdout in
   let old_stderr = dup Unix.stderr in
-  try_lwt
-    let tmp = Filename.temp_file "0install-" "-test-output" in
-    let tmpfd = openfile tmp [O_RDWR] 0o600 in
-    try_lwt
-      dup2 tmpfd Unix.stdout;
-      if include_stderr then dup2 tmpfd Unix.stderr;
-      lwt () = fn () in
-      flush_all ();
-      U.read_file real_system tmp |> Lwt.return
-    finally
-      flush_all ();
-      close tmpfd;
-      unlink tmp;
-      Lwt.return ()
-  finally
-    dup2 old_stdout Unix.stdout; close old_stdout;
-    dup2 old_stderr Unix.stderr; close old_stderr;
-    Lwt.return ()
+  Lwt.finalize
+    (fun () ->
+      let tmp = Filename.temp_file "0install-" "-test-output" in
+      let tmpfd = openfile tmp [O_RDWR] 0o600 in
+      Lwt.finalize
+        (fun () ->
+           dup2 tmpfd Unix.stdout;
+           if include_stderr then dup2 tmpfd Unix.stderr;
+           fn () >|= fun () ->
+           flush_all ();
+           U.read_file real_system tmp
+        )
+        (fun () ->
+           flush_all ();
+           close tmpfd;
+           unlink tmp;
+           Lwt.return ()
+        )
+    )
+    (fun () ->
+       dup2 old_stdout Unix.stdout; close old_stdout;
+       dup2 old_stderr Unix.stderr; close old_stderr;
+       Lwt.return ()
+    )
 
 exception Did_exec
 exception Would_exec of (bool * string array option * string list)
@@ -123,7 +129,7 @@ let src_dir = Filename.dirname ocaml_dir
 let tests_dir = ocaml_dir +/ "tests"
 let test_0install = U.realpath real_system (build_dir +/ "0install")
 
-class fake_system tmpdir =
+class fake_system ?(portable_base=true) tmpdir =
   let extra_files : dentry StringMap.t ref = ref StringMap.empty in
   let hidden_files = ref StringSet.empty in
   let redirect_writes = ref None in
@@ -186,6 +192,11 @@ class fake_system tmpdir =
       | None -> real_system#print_string s
       | Some b -> Buffer.add_string b s
 
+    method std_formatter =
+      match stdout with
+      | None -> real_system#std_formatter
+      | Some b -> Format.formatter_of_buffer b
+
     val mutable argv = [| test_0install |]
 
     method argv = argv
@@ -389,8 +400,12 @@ class fake_system tmpdir =
     initializer
       match tmpdir with
       | Some dir ->
-          self#putenv "ZEROINSTALL_PORTABLE_BASE" dir;
-          Unix.putenv "ZEROINSTALL_PORTABLE_BASE" dir   (* For sub-processes *)
+          let set name value =
+            self#putenv name value;
+            Unix.putenv name value in (* For sub-processes *)
+          if portable_base then (
+            set "ZEROINSTALL_PORTABLE_BASE" dir
+          )
       | None -> ()
 
     method bypass_dryrun = (self :> system)
@@ -416,7 +431,7 @@ let release () =
   Queue.clear download_pools
 
 let make_tools config =
-  let distro = Zeroinstall.Distro_impls.generic_distribution config in
+  let distro = Fake_distro.make config in
   let trust_db = new Zeroinstall.Trust.trust_db config in
   let download_pool = Zeroinstall.Downloader.make_pool ~max_downloads_per_site:2 in
   Queue.add download_pool download_pools;
@@ -428,6 +443,7 @@ let make_tools config =
     method downloader = download_pool#with_monitor ignore
     method make_fetcher watcher = Zeroinstall.Fetch.make config trust_db distro download_pool watcher
     method ui = (null_ui :> Zeroinstall.Ui.ui_handler)
+    method use_gui = No
   end
 
 let fake_log =
@@ -476,11 +492,11 @@ let collect_logging fn =
 
 let collect_logging_lwt fn =
   forward_to_real_log := false;
-  try_lwt
-    fn ()
-  finally
-    forward_to_real_log := true;
-    Lwt.return ()
+  Lwt.finalize fn
+    (fun () ->
+       forward_to_real_log := true;
+       Lwt.return ()
+    )
 
 let format_list l = "[" ^ (String.concat "; " l) ^ "]"
 let equal_str_lists = assert_equal ~printer:format_list
@@ -493,14 +509,19 @@ let assert_raises_safe expected_msg (fn:unit Lazy.t) =
       raise_safe "Error '%s' does not match regexp '%s'" msg expected_msg
 
 let assert_raises_safe_lwt expected_msg fn =
-  try_lwt
-    lwt () = fn () in
-    assert_failure ("Expected Safe_exception " ^ expected_msg)
-  with Safe_exception (msg, _) ->
-    if Str.string_match (Str.regexp expected_msg) msg 0 then
-      Lwt.return ()
-    else
-      raise_safe "Error '%s' does not match regexp '%s'" msg expected_msg
+  Lwt.catch
+    (fun () ->
+       fn () >|= fun () ->
+       assert_failure ("Expected Safe_exception " ^ expected_msg)
+    )
+    (function
+      | Safe_exception (msg, _) ->
+        if Str.string_match (Str.regexp expected_msg) msg 0 then
+          Lwt.return ()
+        else
+          raise_safe "Error '%s' does not match regexp '%s'" msg expected_msg
+      | ex -> Lwt.fail ex
+    )
 
 let temp_dir_name =
   (* Filename.get_temp_dir_name doesn't exist under 3.12 *)
@@ -512,8 +533,7 @@ let temp_dir_name =
         | _ -> failwith "temp_dir_name: unknown filesystem" end
 
 let with_tmpdir fn () =
-  U.finally_do
-    (fun () -> Unix.putenv "ZEROINSTALL_PORTABLE_BASE" "/UNUSED"; Unix.putenv "GNUPGHOME" "/UNUSED") ()
+  U.finally_do reset_env ()
     (fun () ->
       let tmppath = U.make_tmp_dir real_system temp_dir_name ~prefix:"0install-test-" in
       U.finally_do
@@ -524,8 +544,8 @@ let with_tmpdir fn () =
         tmppath fn
     )
 
-let get_fake_config tmpdir =
-  let system = new fake_system tmpdir in
+let get_fake_config ?portable_base tmpdir =
+  let system = new fake_system ?portable_base tmpdir in
   let home =
     match tmpdir with
     | None -> "/home/testuser";
@@ -551,15 +571,20 @@ let get_fake_config tmpdir =
   );
   (Config.get_default_config (system :> system) test_0install, system)
 
-let with_fake_config fn =
+let with_fake_config ?portable_base fn =
   with_tmpdir (fun tmpdir ->
-    get_fake_config (Some tmpdir) |> fn
+    get_fake_config ?portable_base (Some tmpdir) |> fn
   )
 
 let assert_contains expected whole =
   try ignore @@ Str.search_forward (Str.regexp_string expected) whole 0
   with Not_found -> assert_failure (Printf.sprintf "Expected string '%s' not found in '%s'" expected whole)
 
+let assert_matches pattern result =
+  let re = Str.regexp pattern in
+  if not (Str.string_match re result 0) then
+    assert_failure (Printf.sprintf "Result %S doesn't match RE %S" result pattern)
+
 let assert_error_contains expected (fn:unit -> unit) =
   try
     fn ();
@@ -567,18 +592,6 @@ let assert_error_contains expected (fn:unit -> unit) =
   with Safe_exception (msg, _) ->
     assert_contains expected msg
 
-let fake_packagekit status _config =
-  object (_ : Zeroinstall.Packagekit.packagekit)
-    method status = Lwt.return status
-    method get_impls (package_name:string) =
-      log_info "packagekit: get_impls(%s)" package_name;
-      { Zeroinstall.Packagekit.results = []; problems = [] }
-    method check_for_candidates ~ui:_ ~hint (package_names:string list) : unit Lwt.t =
-      log_info "packagekit: check_for_candidates(%s) for %s" (String.concat ", " package_names) hint;
-      Lwt.return ()
-    method install_packages _ui _names = failwith "install_packages"
-  end
-
 (** Read all input from a channel. *)
 let input_all ch =
   let b = Buffer.create 100 in
@@ -593,3 +606,7 @@ let input_all ch =
     failwith "!"
   with End_of_file -> Buffer.contents b
 
+let monitor thread =
+  Lwt.on_failure thread @@ function
+  | Lwt.Canceled -> ()
+  | ex -> log_warning ~ex "Daemon thread failed"
