@@ -32,7 +32,7 @@ exception Ok
 let handle_download_impls config pending_digests impls =
   impls |> List.iter (fun impl ->
     match impl.Impl.impl_type with
-    | `cache_impl {Impl.digests;_} ->
+    | `Cache_impl {Impl.digests;_} ->
         if Zeroinstall.Stores.lookup_maybe config.system digests config.stores = None then (
           let digest_str =
             digests |> U.first_match (fun digest ->
@@ -79,7 +79,7 @@ class fake_slave _config =
       ) in
     pending_feed_downloads := StringMap.remove url !pending_feed_downloads;
     output_string ch contents;
-    `success |> Lwt.return in
+    `Success |> Lwt.return in
 
   object
     method install =
@@ -124,8 +124,8 @@ let suite = "0install">::: [
   "select">:: Fake_system.with_tmpdir (fun tmpdir ->
     let (_config, fake_system) = Fake_system.get_fake_config (Some tmpdir) in
     let system = (fake_system :> system) in
-    fake_system#add_file (tmpdir +/ "cache" +/ "0install.net" +/ "interfaces" +/ "http%3a%2f%2fexample.com%3a8000%2fHello.xml") (feed_dir +/ "Hello.xml");
-    fake_system#add_dir (tmpdir +/ "cache" +/ "0install.net" +/ "implementations") ["sha1=3ce644dc725f1d21cfcf02562c76f375944b266a"];
+    fake_system#add_file (tmpdir +/ "cache" +/ "interfaces" +/ "http%3a%2f%2fexample.com%3a8000%2fHello.xml") (feed_dir +/ "Hello.xml");
+    fake_system#add_dir (tmpdir +/ "cache" +/ "implementations") ["sha1=3ce644dc725f1d21cfcf02562c76f375944b266a"];
     fake_system#add_file "/lib/ld-linux.so.2" "/";    (* Enable multi-arch *)
 
     (* In --offline mode we select from the cached feed *)
@@ -350,8 +350,13 @@ let suite = "0install">::: [
     assert_contains "[dry-run] would write selections to " out;
     assert_contains "[dry-run] would write launcher script " out;
 
-    Unix.mkdir (tmpdir +/ "bin") 0o700;
-    fake_system#putenv "PATH" ((tmpdir +/ "bin") ^ path_sep ^ U.getenv_ex fake_system "PATH");
+    let bin_dir = (tmpdir +/ "bin") in
+    assert (not (fake_system#file_exists bin_dir));
+
+    let out = run ["add"; "local-app-make-bin"; local_feed] in
+    assert_str_equal "" out;
+
+    assert (fake_system#file_exists bin_dir);
 
     let out = run ["add"; "local-app"; local_feed] in
     assert_str_equal "" out;
@@ -703,6 +708,15 @@ let suite = "0install">::: [
 
     let get_value name = run_0install fake_system ["config"; name] in
 
+    let injector_dir = fake_system#tmpdir +/ "config/injector" in
+    assert_equal ~msg:"init no config" false (fake_system#file_exists injector_dir);
+
+    run_0install fake_system ["config"; "--dry-run"; "help_with_testing"; "false"]
+    |> Fake_system.assert_matches "^\\[dry-run] Would write config to .*/config/injector/global";
+    Zeroinstall.Config.load_config config;
+    assert_equal false config.help_with_testing;
+    assert_equal ~msg:"no config dir created" false (fake_system#file_exists injector_dir);
+
     assert_str_equal "30d\n" @@ get_value "freshness";
     assert_str_equal "full\n" @@ get_value "network_use";
     assert_str_equal "False\n" @@ get_value "help_with_testing";
@@ -711,6 +725,8 @@ let suite = "0install">::: [
     assert_str_equal "" @@ run_0install fake_system ["config"; "help_with_testing"; "True"];
     assert_str_equal "" @@ run_0install fake_system ["config"; "network_use"; "minimal"];
 
+    assert_equal ~msg:"config dir exists" true (fake_system#file_exists injector_dir);
+
     Zeroinstall.Config.load_config config;
     assert_equal (Some (5. *. 60.)) @@ config.freshness;
     assert_equal Minimal_network config.network_use;
@@ -736,7 +752,7 @@ let suite = "0install">::: [
     assert_contains "Usage:" out;
     assert_contains "FEED" out;
 
-    lwt () = Support.Gpg.import_key config.system (U.read_file config.system (feed_dir +/ "6FCF121BE2390E0B.gpg")) in
+    Support.Gpg.import_key config.system (U.read_file config.system (feed_dir +/ "6FCF121BE2390E0B.gpg")) >>= fun () ->
     let out = run_0install fake_system ~include_stderr:true ["import"; feed_dir +/ "Hello.xml"] ~stdin:"Y\n" in
     assert_contains "Do you want to trust this key to sign feeds from 'example.com:8000'?" out;
     Fake_system.fake_log#assert_contains "Trusting DE937DD411906ACF7C263B396FCF121BE2390E0B for example.com:8000";
@@ -756,7 +772,7 @@ let suite = "0install">::: [
     let out = run_0install fake_system ["list"] in
     assert_str_equal "" out;
 
-    lwt () = Support.Gpg.import_key config.system (U.read_file config.system (feed_dir +/ "6FCF121BE2390E0B.gpg")) in
+    Support.Gpg.import_key config.system (U.read_file config.system (feed_dir +/ "6FCF121BE2390E0B.gpg")) >>= fun () ->
     ignore @@ run_0install fake_system ~include_stderr:true ["import"; feed_dir +/ "Hello.xml"] ~stdin:"Y\n";
 
     let out = run_0install fake_system ["list"] in
@@ -776,10 +792,11 @@ let suite = "0install">::: [
     assert (U.starts_with out "Usage:")
   );
 
-  "list">:: Fake_system.with_fake_config (fun (config, fake_system) ->
+  "list2">:: Fake_system.with_fake_config ~portable_base:false (fun (config, fake_system) ->
     let out = run_0install fake_system ["list"] in
     assert_str_equal "" out;
-    let cached_ifaces = List.hd config.basedirs.Support.Basedir.cache +/ "0install.net" +/ "interfaces" in
+    let basedirs = Support.Basedir.get_default_config config.system in
+    let cached_ifaces = List.hd basedirs.Support.Basedir.cache +/ "0install.net" +/ "interfaces" in
 
     U.makedirs config.system cached_ifaces 0o700;
     U.touch config.system @@ cached_ifaces +/ "file%3a%2f%2ffoo";
@@ -868,7 +885,7 @@ let suite = "0install">::: [
   "logging">:: Fake_system.with_fake_config (fun (_config, fake_system) ->
     let out = run_0install fake_system ["-v"; "list"; "UNKNOWN"] in
     assert_str_equal "" out;
-    Fake_system.fake_log#assert_contains "0install (OCaml version): verbose mode on";
+    Fake_system.fake_log#assert_contains "0install .* (OCaml version): verbose mode on";
   );
 
   "help2">:: Fake_system.with_fake_config (fun (_config, fake_system) ->
