@@ -19,7 +19,7 @@ let suite = "apps">::: [
 
     fake_system#add_file "/lib/ld-linux.so.2" "/";    (* Enable multi-arch *)
 
-    let interface_cache = tmpdir +/ "cache/0install.net/interfaces" in
+    let interface_cache = tmpdir +/ "cache/interfaces" in
     U.makedirs system interface_cache 0o755;
     U.copy_file system
       "../tests/Hello.xml"
@@ -36,12 +36,11 @@ let suite = "apps">::: [
     let app = Fake_system.expect @@ Apps.lookup_app config "hello" in
     Fake_system.assert_str_equal url (Apps.get_requirements system app).R.interface_uri;
 
-    ignore @@ Support.Basedir.save_path system
-      ("0install.net" +/ "implementations" +/ "sha1=3ce644dc725f1d21cfcf02562c76f375944b266a")
-      config.basedirs.Support.Basedir.cache;
+    let impl_dir = Zeroinstall.Paths.Cache.(save_path implementations) config.paths in
+    U.makedirs system (impl_dir +/ "sha1=3ce644dc725f1d21cfcf02562c76f375944b266a") 0o755;
 
     (* Initialise the new app with selections for version 0.1-pre *)
-    let distro = Zeroinstall.Distro_impls.generic_distribution config in
+    let distro = Fake_distro.make config in
     let feed_provider = new Zeroinstall.Feed_provider_impl.feed_provider config distro in
     let () =
       match Zeroinstall.Solver.solve_for config feed_provider r with
