@@ -22,6 +22,9 @@ let run_0install = Test_0install.run_0install
 
 let binary iface = {Selections.iface; source = false}
 
+let config_site = "0install.net"
+let config_prog = "injector"
+
 exception Open_gui
 
 let parse_sels xml =
@@ -238,10 +241,10 @@ let suite = "download">::: [
       "\\[dry-run] downloading feed from http://localhost:8000/Hello\n\
        \\[dry-run] asking http://localhost:3333/key-info about key DE937DD411906ACF7C263B396FCF121BE2390E0B\n\
        \\[dry-run] would trust key DE937DD411906ACF7C263B396FCF121BE2390E0B for localhost:8000\n\
-       \\[dry-run] would update trust database .*/config/0install.net/injector/trustdb.xml\n\
-       \\[dry-run] would cache feed http://localhost:8000/Hello as .*/cache/0install.net/interfaces/http%3a%2f%2flocalhost%3a8000%2fHello\n\
+       \\[dry-run] would update trust database .*/config/injector/trustdb.xml\n\
+       \\[dry-run] would cache feed http://localhost:8000/Hello as .*/cache/interfaces/http%3a%2f%2flocalhost%3a8000%2fHello\n\
        \\[dry-run] downloading http://localhost:8000/HelloWorld.tgz\n\
-       \\[dry-run] would store implementation as .*/cache/0install.net/implementations/sha1=3ce644dc725f1d21cfcf02562c76f375944b266a\n\
+       \\[dry-run] would store implementation as .*/cache/implementations/sha1=3ce644dc725f1d21cfcf02562c76f375944b266a\n\
        \\[dry-run] would execute: .*HelloWorld/main Hello\n" in
     if not (Str.string_match (Str.regexp expected) out 0) then
       raise_safe "No match. Got:\n%s" out;
@@ -252,7 +255,7 @@ let suite = "download">::: [
       run_0install fake_system ["import"; "-v"; "NO-SUCH-FILE"] |> ignore
     ));
 
-    assert_equal None @@ FC.get_cached_feed config (`remote_feed "http://localhost:8000/Hello");
+    assert_equal None @@ FC.get_cached_feed config (`Remote_feed "http://localhost:8000/Hello");
 
     server#expect [
       [("6FCF121BE2390E0B.gpg", `Serve)];
@@ -269,7 +272,7 @@ let suite = "download">::: [
     assert (trust_db#is_trusted ~domain "DE937DD411906ACF7C263B396FCF121BE2390E0B");
 
     (* Check we imported the interface after trusting the key *)
-    let hello = FC.get_cached_feed config (`remote_feed "http://localhost:8000/Hello") |> Fake_system.expect in
+    let hello = FC.get_cached_feed config (`Remote_feed "http://localhost:8000/Hello") |> Fake_system.expect in
     assert_equal 1 @@ StringMap.cardinal hello.F.implementations;
 
     (* Shouldn't need to prompt the second time *)
@@ -278,12 +281,12 @@ let suite = "download">::: [
   );
 
   "distro">:: Server.with_server (fun (config, fake_system) server ->
-    Zeroinstall.Packagekit.packagekit := Fake_system.fake_packagekit (`Unavailable "Use apt-cache");
+    let packagekit = lazy (Fake_distro.fake_packagekit (`Unavailable "Use apt-cache")) in
     let native_url = "http://example.com:8000/Native.xml" in
     fake_system#set_spawn_handler (Some Fake_system.real_spawn_handler);
 
     (* Initially, we don't have the feed at all... *)
-    assert_equal None @@ FC.get_cached_feed config (`remote_feed native_url);
+    assert_equal None @@ FC.get_cached_feed config (`Remote_feed native_url);
 
     server#expect [
       [("Native.xml", `Serve)];
@@ -294,14 +297,14 @@ let suite = "download">::: [
       run_0install fake_system ["download"; native_url] |> ignore
     ));
 
-    let feed = Fake_system.expect @@ FC.get_cached_feed config (`remote_feed native_url) in
+    let feed = Fake_system.expect @@ FC.get_cached_feed config (`Remote_feed native_url) in
     assert_equal 0 @@ StringMap.cardinal feed.F.implementations;
 
     let dpkgdir = Test_0install.feed_dir +/ "dpkg" in
     let old_path = Unix.getenv "PATH" in
     Unix.putenv "PATH" (dpkgdir ^ ":" ^ old_path);
     fake_system#putenv "PATH" (dpkgdir ^ ":" ^ old_path);
-    let deb = Zeroinstall.Distro_impls.Debian.debian_distribution ~status_file:(dpkgdir +/ "status") config in
+    let deb = Zeroinstall.Distro_impls.Debian.debian_distribution ~status_file:(dpkgdir +/ "status") ~packagekit config in
 
     Fake_system.fake_log#reset;
     Lwt_main.run @@ deb#check_for_candidates ~ui:Fake_system.null_ui feed;
@@ -691,7 +694,7 @@ let suite = "download">::: [
   "replay">:: Server.with_server (fun (config, fake_system) server ->
     let iface = "http://example.com:8000/Hello.xml" in
     let system = config.system in
-    let cached = FC.get_save_cache_path config (`remote_feed iface) in
+    let cached = FC.get_save_cache_path config (`Remote_feed iface) in
     U.copy_file system (Test_0install.feed_dir +/ "Hello-new.xml") cached 0o644;
 
     let trust_db = new Zeroinstall.Trust.trust_db config in
@@ -737,7 +740,7 @@ let suite = "download">::: [
     let iface = Test_0install.feed_dir +/ "Binary.xml" in
     Fake_system.assert_raises_safe "Error downloading 'http://localhost/missing.png': \
                                     The requested URL returned error: 404" (lazy (
-      Lwt_main.run @@ Zeroinstall.Gui.download_icon (tools#make_fetcher tools#ui#watcher) feed_provider (`local_feed iface);
+      Lwt_main.run @@ Zeroinstall.Gui.download_icon (tools#make_fetcher tools#ui#watcher) feed_provider (`Local_feed iface);
     ));
   );
 
@@ -754,7 +757,7 @@ let suite = "download">::: [
     assert_contains "Firefox - Webbrowser" out
   );
 
-  "select">:: Server.with_server (fun (config, fake_system) server ->
+  "select">:: Server.with_server ~portable_base:false (fun (config, fake_system) server ->
     server#expect [
       [("Hello.xml", `Serve)];
       [("6FCF121BE2390E0B.gpg", `Serve)];
@@ -766,9 +769,10 @@ let suite = "download">::: [
 
     (* Check background select - update metadata only *)
     let url = "http://example.com:8000/Hello.xml" in
-    F.save_feed_overrides config (`remote_feed url) F.({last_checked = None; user_stability = StringMap.empty});
+    F.save_feed_overrides config (`Remote_feed url) F.({last_checked = None; user_stability = StringMap.empty});
     let rel_path = config_site +/ config_prog +/ "last-check-attempt" +/ Zeroinstall.Escape.pretty url in
-    let last_check_attempt = B.load_first config.system rel_path config.basedirs.B.cache |> expect in
+    let basedirs = Support.Basedir.get_default_config config.system in
+    let last_check_attempt = B.load_first config.system rel_path basedirs.B.cache |> expect in
     fake_system#unlink last_check_attempt;
 
     fake_system#allow_spawn_detach true;
@@ -780,4 +784,43 @@ let suite = "download">::: [
     assert_contains "Version: 1\n" out;
     assert_contains "(not cached)" out;
   );
+
+  "slave-2.6">::  Server.with_server ~portable_base:false (fun (config, _fake_system) server ->
+    server#expect [
+      [("Hello.xml", `Serve)];
+      [("6FCF121BE2390E0B.gpg", `Serve)];
+      [("DE937DD411906ACF7C263B396FCF121BE2390E0B", `AcceptKey)];
+    ];
+    let tools = Fake_system.make_tools config in
+    let from_peer, to_slave = Lwt_io.pipe () in
+    let from_slave, to_peer = Lwt_io.pipe () in
+    let requested_api_version = Version.parse "2.6" in
+    let slave = Slave.run_slave config tools ~from_peer ~to_peer ~requested_api_version in
+    Fake_system.monitor slave;
+    let callback _conn (x, _) = failwith x in
+    Lwt_main.run begin
+      Json_connection.client ~from_peer:from_slave ~to_peer:to_slave callback
+      >>= fun (client, client_thread, version) ->
+      Fake_system.monitor client_thread;
+      OUnit.assert_equal "2.6" (Version.to_string version);
+      Json_connection.invoke client "select" [
+        `Assoc [
+          "interface", `String "http://example.com:8000/Hello.xml";
+        ];
+        `Bool false
+      ] >>= begin function
+      | `WithXML (`List [`String "ok"], xml) -> Lwt.return xml
+      | x -> raise_safe "Bad reply %a" Json_connection.pp_opt_xml x
+      end >>= fun xml ->
+      let sels = Selections.create xml in
+      let impl = Selections.(get_selected (root_role sels) sels) |> expect in
+      Selections.get_id impl |> assert_equal { Feed_url.
+        feed = `Remote_feed "http://example.com:8000/Hello.xml";
+        id = "sha1=3ce644dc725f1d21cfcf02562c76f375944b266a"
+      };
+      Lwt.cancel slave;
+      Lwt.cancel client_thread;
+      Lwt.return ()
+    end
+  );
 ]
