@@ -13,13 +13,14 @@ module G = Support.Gpg
 module Q = Support.Qdom
 module Basedir = Support.Basedir
 
+let config_site = "0install.net"
 let cache_path_for config url = Feed_cache.get_save_cache_path config url
 
 let suite = "feed-cache">::: [
   "is-stale">:: Fake_system.with_tmpdir (fun tmpdir ->
     let (config, fake_system) = Fake_system.get_fake_config (Some tmpdir) in
 
-    let url = `remote_feed "http://localhost:8000/Hello" in
+    let url = `Remote_feed "http://localhost:8000/Hello" in
 
     fake_system#add_file (cache_path_for config url) (Test_0install.feed_dir +/ "Hello");
 
@@ -40,7 +41,7 @@ let suite = "feed-cache">::: [
   );
 
   "check-attempt">:: Fake_system.with_fake_config (fun (config, fake_system) ->
-    let bar = `remote_feed "http://foo/bar.xml" in
+    let bar = `Remote_feed "http://foo/bar.xml" in
     assert_equal None @@ Feed_cache.get_last_check_attempt config bar;
 
     fake_system#set_time 100.0;
@@ -50,7 +51,7 @@ let suite = "feed-cache">::: [
       | Some 100.0 -> ()
       | _ -> assert false in
 
-    assert_equal None @@ Feed_cache.get_last_check_attempt config (`remote_feed "http://foo/bar2.xml")
+    assert_equal None @@ Feed_cache.get_last_check_attempt config (`Remote_feed "http://foo/bar2.xml")
   );
 
   "check-signed">:: Fake_gpg_agent.with_gpg (fun tmpdir ->
@@ -58,32 +59,34 @@ let suite = "feed-cache">::: [
     let trust_db = new Zeroinstall.Trust.trust_db config in
     trust_db#trust_key "92429807C9853C0744A68B9AAE07828059A53CC1" ~domain:"foo";
     let download_pool = Zeroinstall.Downloader.make_pool ~max_downloads_per_site:2 in
-    let distro = Zeroinstall.Distro_impls.generic_distribution config in
+    let distro = Fake_distro.make config in
     let fetcher = Zeroinstall.Fetch.make config trust_db distro download_pool Fake_system.null_ui in
     let foo_signed_xml = U.read_file config.system (Fake_system.tests_dir +/ "foo.xml") in
 
     (* Unsigned *)
-    lwt () = Fake_system.assert_raises_safe_lwt
+    Fake_system.assert_raises_safe_lwt
       "This is not a Zero Install feed! It should be an XML document, but it starts:\nhello"
-      (fun () -> G.verify config.system "hello" >|= ignore) in
+      (fun () -> G.verify config.system "hello" >|= ignore)
+    >>= fun () ->
 
-    lwt () = G.import_key config.system Test_gpg.thomas_key in
+    G.import_key config.system Test_gpg.thomas_key >>= fun () ->
 
     (* Signed, wrong URL *)
-    lwt () = Fake_system.assert_raises_safe_lwt
+    Fake_system.assert_raises_safe_lwt
       ("URL mismatch in feed:\n\
         http://foo/wrong expected\n\
         http://foo/ given in 'uri' attribute on <interface> at http://foo/wrong:3:97")
-      (fun () -> fetcher#import_feed (`remote_feed "http://foo/wrong") foo_signed_xml) in
+      (fun () -> fetcher#import_feed (`Remote_feed "http://foo/wrong") foo_signed_xml)
+    >>= fun () ->
 
     (* Signed *)
-    let feed_url = `remote_feed "http://foo/" in
-    lwt () = fetcher#import_feed feed_url foo_signed_xml in
+    let feed_url = `Remote_feed "http://foo/" in
+    fetcher#import_feed feed_url foo_signed_xml >>= fun () ->
 
     assert_equal ["http://foo/"] @@ StringSet.elements @@ Feed_cache.list_all_feeds config;
 
     let new_xml = Feed_cache.get_cached_feed_path config feed_url |> Fake_system.expect |> U.read_file config.system in
-    lwt (sigs, _) = G.verify config.system new_xml in
+    G.verify config.system new_xml >>= fun (sigs, _) ->
     let last_modified = trust_db#oldest_trusted_sig "foo" sigs in
     assert_equal (Some 1380109390.) last_modified;
 
@@ -91,12 +94,12 @@ let suite = "feed-cache">::: [
     let foo_signed_xml_new = U.read_file config.system (Fake_system.tests_dir +/ "foo-new.xml") in
 
     let dryrun_fetcher = Zeroinstall.Fetch.make {config with dry_run = true} trust_db distro download_pool Fake_system.null_ui in
-    lwt out = Fake_system.capture_stdout_lwt (fun () ->
+    Fake_system.capture_stdout_lwt (fun () ->
       dryrun_fetcher#import_feed feed_url foo_signed_xml_new
-    ) in
+    ) >>= fun out ->
     assert (U.starts_with out "[dry-run] would cache feed http://foo/ as");
 
-    lwt () = fetcher#import_feed feed_url foo_signed_xml_new in
+    fetcher#import_feed feed_url foo_signed_xml_new >>= fun () ->
 
     (* Can't 'update' to an older copy *)
     Fake_system.assert_raises_safe_lwt
@@ -108,9 +111,10 @@ let suite = "feed-cache">::: [
       (fun () -> fetcher#import_feed feed_url foo_signed_xml)
   );
 
-  "test-list">:: Fake_system.with_fake_config (fun (config, _fake_system) ->
+  "test-list">:: Fake_system.with_fake_config ~portable_base:false (fun (config, _fake_system) ->
     assert (StringSet.is_empty @@ Feed_cache.list_all_feeds config);
-    let iface_dir = Basedir.save_path config.system (config_site +/ "interfaces") config.basedirs.Basedir.cache in
+    let basedirs = Support.Basedir.get_default_config config.system in
+    let iface_dir = Basedir.save_path config.system (config_site +/ "interfaces") basedirs.Basedir.cache in
     U.touch config.system (iface_dir +/ "http%3a%2f%2ffoo");
     Fake_system.equal_str_lists ["http://foo"] @@ (StringSet.elements @@ Feed_cache.list_all_feeds config)
   );
@@ -127,8 +131,8 @@ let suite = "feed-cache">::: [
     Feed_cache.save_iface_config config iface {
       Feed_cache.stability_policy = Some Developer;
       Feed_cache.extra_feeds = [
-        { F.feed_src = `remote_feed "http://sys-feed"; F.feed_os = None; F.feed_machine = None; F.feed_langs = None; F.feed_type = F.Distro_packages };
-        { F.feed_src = `remote_feed "http://user-feed"; F.feed_os = Some Arch.linux; F.feed_machine = None; F.feed_langs = None; F.feed_type = F.User_registered };
+        { F.feed_src = `Remote_feed "http://sys-feed"; F.feed_os = None; F.feed_machine = None; F.feed_langs = None; F.feed_type = F.Distro_packages };
+        { F.feed_src = `Remote_feed "http://user-feed"; F.feed_os = Some Arch.linux; F.feed_machine = None; F.feed_langs = None; F.feed_type = F.User_registered };
       ];
     };
 
@@ -136,11 +140,11 @@ let suite = "feed-cache">::: [
     let iface_config = Feed_cache.load_iface_config config iface in
     assert_equal (Some Developer) iface_config.Feed_cache.stability_policy;
     begin match iface_config.Feed_cache.extra_feeds with
-    | [ {F.feed_src = `remote_feed "http://user-feed"; F.feed_os; F.feed_machine = None; _ } ] when feed_os = Some Arch.linux -> ()
+    | [ {F.feed_src = `Remote_feed "http://user-feed"; F.feed_os; F.feed_machine = None; _ } ] when feed_os = Some Arch.linux -> ()
     | _ -> assert false end;
   );
 
-  "site-packages">:: Fake_system.with_fake_config (fun (config, _fake_system) ->
+  "site-packages">:: Fake_system.with_fake_config ~portable_base:false (fun (config, _fake_system) ->
     (* The old system (0install < 1.9):
      * - 0compile stores implementations to ~/.cache, and
      * - adds to extra_feeds
@@ -161,9 +165,10 @@ let suite = "feed-cache">::: [
 
     let expected_escape = "section__prog_5f_1.xml" in
 
+    let basedirs = Support.Basedir.get_default_config config.system in
     let meta_dir = Basedir.save_path config.system
       ("0install.net" +/ "site-packages" +/ "http" +/ "example.com" +/ expected_escape +/ "1.0" +/ "0install")
-      config.basedirs.Basedir.data in
+      basedirs.Basedir.data in
     let feed = meta_dir +/ "feed.xml" in
     U.copy_file config.system (Test_0install.feed_dir +/ "Local.xml") feed 0o644;
 
@@ -177,8 +182,8 @@ let suite = "feed-cache">::: [
     (* Check that we write it out, so that older 0installs can find it *)
     Feed_cache.save_iface_config config iface iface_config;
 
-    let config_file = Fake_system.expect @@ Config.load_first_config ("0install.net" +/ "injector" +/
-                                            "interfaces" +/ "http:##example.com#section#prog_1.xml") config in
+    let config_file = Fake_system.expect @@ Basedir.load_first config.system ("0install.net" +/ "injector" +/
+                          "interfaces" +/ "http:##example.com#section#prog_1.xml") basedirs.Basedir.config in
     let doc = Q.parse_file config.system config_file in
 
     let is_feed elem = (ZI.tag elem = Some "feed") in
@@ -192,7 +197,7 @@ let suite = "feed-cache">::: [
     (* Check feeds are automatically removed again *)
     let site_dir = Fake_system.expect @@ Basedir.load_first config.system
       ("0install.net" +/ "site-packages" +/ "http" +/ "example.com" +/ expected_escape)
-      config.basedirs.Basedir.data in
+      basedirs.Basedir.data in
     U.rmtree config.system ~even_if_locked:false site_dir;
 
     let iface_config = Feed_cache.load_iface_config config iface in
