@@ -28,6 +28,9 @@ let () =
 
 let session ?switch () =
   Lwt.catch (fun () ->
+    begin try if Sys.getenv "DBUS_SESSION_BUS_ADDRESS" = "DBUS_SESSION_UNUSED" then
+      failwith "Disabled for unit-tests"
+    with Not_found -> () end;
     (* Prevent OBus from killing us. *)
     OBus_bus.session ?switch () >>= fun session_bus ->
     OBus_connection.set_on_disconnect session_bus (fun ex -> log_info ~ex "D-BUS disconnect"; return ());
@@ -40,6 +43,9 @@ let session ?switch () =
 
 let system () =
   Lwt.catch (fun () ->
+      begin try if Sys.getenv "DBUS_SYSTEM_BUS_ADDRESS" = "DBUS_SYSTEM_UNUSED" then
+        failwith "Disabled for unit-tests"
+      with Not_found -> () end;
       OBus_bus.system () >|= fun system_bus -> `Ok system_bus
     )
     (fun ex ->
@@ -136,7 +142,12 @@ module OBus_value =
   struct
     module C =
       struct
+        exception Signature_mismatch
         let array _ = ()
+        let dict _ _ = ()
+        let string = ()
+        let variant = ()
+        let cast_single _ = failwith "cast_single"
         let basic_boolean = ()
         let basic_uint32 = ()
         let basic_uint64 = ()
@@ -145,6 +156,10 @@ module OBus_value =
         type 'a sequence = 'a list
       end
 
+    module V = struct
+      let string_of_single _ = ""
+    end
+
     type 'a arguments = unit
 
     let arg0 = ()
