@@ -12,13 +12,12 @@ module U = Support.Utils
 open Distro
 
 (** Base class for platforms that can use PackageKit *)
-class virtual packagekit_distro config =
+class virtual packagekit_distro ~(packagekit:Packagekit.packagekit Lazy.t) config =
   object (self)
     inherit distribution config
 
-    val packagekit = !Packagekit.packagekit (Support.Locale.LangMap.choose config.langs |> fst)
-
     method private get_package_impls query =
+      let packagekit = Lazy.force packagekit in
       let package_name = query.package_name in
       let pk_unavailable reason = query.problem (Printf.sprintf "%s: %s" package_name reason) in
       match Lwt.state packagekit#status with
@@ -31,8 +30,8 @@ class virtual packagekit_distro config =
           pk_query.Packagekit.results |> List.iter (fun info ->
             let {Packagekit.version; Packagekit.machine; Packagekit.installed; Packagekit.retrieval_method} = info in
             let package_state =
-              if installed then `installed
-              else `uninstalled retrieval_method in
+              if installed then `Installed
+              else `Uninstalled retrieval_method in
             self#add_package_implementation
               ~version
               ~machine
@@ -44,6 +43,7 @@ class virtual packagekit_distro config =
 
     (* This default implementation queries PackageKit, if available. *)
     method check_for_candidates ~ui feed =
+      let packagekit = Lazy.force packagekit in
       match get_matching_package_impls self feed with
       | [] -> Lwt.return ()
       | matches ->
@@ -57,13 +57,14 @@ class virtual packagekit_distro config =
     method! install_distro_packages ui typ items =
       match typ with
       | "packagekit" ->
+          let packagekit = Lazy.force packagekit in
           begin packagekit#install_packages ui items >>= function
-          | `cancel -> Lwt.return `cancel
-          | `ok ->
+          | `Cancel -> Lwt.return `Cancel
+          | `Ok ->
               items |> List.iter (fun (impl, _rm) ->
                 self#fixup_main impl
               );
-              Lwt.return `ok end
+              Lwt.return `Ok end
       | _ ->
           let names = items |> List.map (fun (_impl, rm) -> snd rm.Impl.distro_install_info) in
           ui#confirm (Printf.sprintf
@@ -72,9 +73,9 @@ class virtual packagekit_distro config =
              use that to install things. The packages are:\n\n- %s" typ (String.concat "\n- " names))
   end
 
-let generic_distribution config =
+let generic_distribution ~packagekit config =
   object
-    inherit packagekit_distro config
+    inherit packagekit_distro ~packagekit config
     val check_host_python = true
     val distro_name = "fallback"
     val id_prefix = "package:fallback"
@@ -98,7 +99,7 @@ let check_cache id_prefix elem cache =
   let package = Element.package elem in
   let sel_id = Element.id elem in
   let matches (installed_version, machine) =
-    let installed_id = Printf.sprintf "%s:%s:%a:%s" id_prefix package Version.fmt installed_version (Arch.format_machine_or_star machine) in
+    let installed_id = Support.Logging.asprintf "%s:%s:%a:%s" id_prefix package Version.fmt installed_version (Arch.format_machine_or_star machine) in
     (* log_warning "Want %s %s, have %s" package sel_id installed_id; *)
     sel_id = installed_id in
   List.exists matches (fst (Distro_cache.get cache package))
@@ -118,7 +119,7 @@ module Debian = struct
     size : Int64.t option;
   }
 
-  let debian_distribution ?(status_file=dpkg_db_status) config =
+  let debian_distribution ?(status_file=dpkg_db_status) ~packagekit config =
     let apt_cache = Hashtbl.create 10 in
     let system = config.system in
 
@@ -126,10 +127,10 @@ module Debian = struct
     let query_apt_cache package_names =
       package_names |> Lwt_list.iter_s (fun package ->
         (* Check to see whether we could get a newer version using apt-get *)
-        lwt result =
-          try_lwt
+        Lwt.catch
+          (fun () ->
             let stderr = if Support.Logging.will_log Support.Logging.Debug then None else Some `Dev_null in
-            lwt out = Lwt_process.pread ?stderr (U.make_command system ["apt-cache"; "--no-all-versions"; "show"; "--"; package]) in
+            Lwt_process.pread ?stderr (U.make_command system ["apt-cache"; "--no-all-versions"; "show"; "--"; package]) >>= fun out ->
             let machine = ref None in
             let version = ref None in
             let size = ref None in
@@ -149,9 +150,12 @@ module Debian = struct
             match !version, !machine with
             | Some version, Some machine -> Lwt.return (Some {version; machine; size = !size})
             | _ -> Lwt.return None
-          with ex ->
+          )
+          (fun ex ->
             log_warning ~ex "'apt-cache show %s' failed" package;
-            Lwt.return None in
+            Lwt.return None
+          )
+        >>= fun result ->
         (* (multi-arch support? can there be multiple candidates?) *)
         Hashtbl.replace apt_cache package result;
         Lwt.return ()
@@ -209,7 +213,7 @@ module Debian = struct
       ) in
 
     object (self : #Distro.distribution)
-      inherit packagekit_distro config as super
+      inherit packagekit_distro ~packagekit config as super
       val check_host_python = false
 
       val distro_name = "Debian"
@@ -224,6 +228,7 @@ module Debian = struct
         check_cache id_prefix elem cache || super#is_installed elem
 
       method! private get_package_impls query =
+        let packagekit = Lazy.force packagekit in
         let package_name = query.package_name in
         (* Add any PackageKit candidates *)
         begin match Lwt.state packagekit#status with
@@ -235,7 +240,7 @@ module Debian = struct
               match Hashtbl.find apt_cache package_name with
               | Some {version; machine; size = _} ->
                   let machine = Arch.parse_machine machine in
-                  let package_state = `uninstalled Impl.({distro_size = None; distro_install_info = ("apt-get install", package_name)}) in
+                  let package_state = `Uninstalled Impl.({distro_size = None; distro_install_info = ("apt-get install", package_name)}) in
                   self#add_package_implementation ~package_state ~version ~machine ~quick_test:None ~distro_name query
               | None ->
                   query.problem (Printf.sprintf "%s: not known to apt-cache" package_name)
@@ -244,21 +249,22 @@ module Debian = struct
         (* Add installed packages by querying dpkg. *)
         let infos, quick_test = Distro_cache.get cache package_name in
         infos |> List.iter (fun (version, machine) ->
-          self#add_package_implementation ~package_state:`installed ~version ~machine ~quick_test ~distro_name query
+          self#add_package_implementation ~package_state:`Installed ~version ~machine ~quick_test ~distro_name query
         )
 
       method! check_for_candidates ~ui feed =
         match Distro.get_matching_package_impls self feed with
         | [] -> Lwt.return ()
         | matches ->
+            let packagekit = Lazy.force packagekit in
             let package_names = matches |> List.map (fun (elem, _props) -> (Element.package elem)) in
 
             (* Check apt-cache to see whether we have the pacakges. If PackageKit isn't available, we'll use these
              * results directly. If it is available, we'll use these results to filter the PackageKit query, because
              * it doesn't like queries for missing packages (it tends to abort the query early and miss some results). *)
-            lwt () = query_apt_cache package_names
-            and pkgkit_status = packagekit#status in
-
+            let apt = query_apt_cache package_names in
+            packagekit#status >>= fun pkgkit_status ->
+            apt >>= fun () ->
             match pkgkit_status with
             | `Ok ->
                 let hint = Feed_url.format_url feed.Feed.url in
@@ -295,7 +301,7 @@ end
 module RPM = struct
   let rpm_db_packages = "/var/lib/rpm/Packages"
 
-  let rpm_distribution ?(rpm_db_packages = rpm_db_packages) config =
+  let rpm_distribution ?(rpm_db_packages = rpm_db_packages) ~packagekit config =
     let fixup_java_main impl java_version =
       (* (note: on Fedora, unlike Debian, the arch is x86_64, not amd64) *)
 
@@ -333,7 +339,7 @@ module RPM = struct
       ) in
 
     object (self)
-      inherit packagekit_distro config as super
+      inherit packagekit_distro ~packagekit config as super
       val check_host_python = false
 
       val distro_name = "RPM"
@@ -347,7 +353,7 @@ module RPM = struct
         (* Add installed packages by querying rpm *)
         let infos, quick_test = Distro_cache.get cache query.package_name in
         infos |> List.iter (fun (version, machine) ->
-          self#add_package_implementation ~package_state:`installed ~version ~machine ~quick_test ~distro_name query
+          self#add_package_implementation ~package_state:`Installed ~version ~machine ~quick_test ~distro_name query
         )
 
       method! private is_installed elem =
@@ -384,7 +390,7 @@ end
 module ArchLinux = struct
   let arch_db = "/var/lib/pacman"
 
-  let arch_distribution ?(arch_db=arch_db) config =
+  let arch_distribution ?(arch_db=arch_db) ~packagekit config =
     let packages_dir = arch_db ^ "/local" in
     let parse_dirname entry =
       try
@@ -428,7 +434,7 @@ module ArchLinux = struct
       | _ -> items in
 
     object (self : #Distro.distribution)
-      inherit packagekit_distro config as super
+      inherit packagekit_distro ~packagekit config as super
       val check_host_python = false
 
       val distro_name = "Arch"
@@ -457,7 +463,7 @@ module ArchLinux = struct
                 | Some version ->
                     let machine = Arch.parse_machine machine in
                     let quick_test = Some (desc_path, Exists) in
-                    self#add_package_implementation ~package_state:`installed ~version ~machine ~quick_test ~distro_name query
+                    self#add_package_implementation ~package_state:`Installed ~version ~machine ~quick_test ~distro_name query
     end
 end
 
@@ -508,7 +514,7 @@ module Mac = struct
             try_cleanup_distro_version_warn (get_version main) query.package_name |> if_some (fun version ->
               self#add_package_implementation
                 ~main
-                ~package_state:`installed
+                ~package_state:`Installed
                 ~version
                 ~machine:(Some host_machine)
                 ~quick_test:(Some (main, UnchangedSince info.Unix.st_mtime))
@@ -526,7 +532,7 @@ module Mac = struct
           | Some info ->
               self#add_package_implementation
                 ~main
-                ~package_state:`installed
+                ~package_state:`Installed
                 ~version:(Version.parse zero_version)
                 ~machine:(Arch.parse_machine machine)
                 ~quick_test:(Some (main, UnchangedSince info.Unix.st_mtime))
@@ -596,7 +602,7 @@ module Mac = struct
       method private get_package_impls query =
         let infos, quick_test = Distro_cache.get cache query.package_name in
         infos |> List.iter (fun (version, machine) ->
-          self#add_package_implementation ~package_state:`installed ~version ~machine ~quick_test ~distro_name query
+          self#add_package_implementation ~package_state:`Installed ~version ~machine ~quick_test ~distro_name query
         );
         darwin#get_package_impls query
 
@@ -661,8 +667,8 @@ module Win = struct
           | Some install, machine ->
               let version = Version.parse zero_version in
               let package_state =
-                if install = 1 then `installed
-                else `uninstalled Impl.({distro_size = None; distro_install_info = ("Windows installer", "NetFX")}) in
+                if install = 1 then `Installed
+                else `Uninstalled Impl.({distro_size = None; distro_install_info = ("Windows installer", "NetFX")}) in
               self#add_package_implementation
                 ~main:""      (* .NET executables do not need a runner on Windows but they need one elsewhere *)
                 ~package_state
@@ -682,8 +688,8 @@ module Win = struct
           | Some install, Some release, machine ->
               let version = Version.parse zero_version in
               let package_state =
-                if install = 1 && release >= release_version then `installed
-                else `uninstalled Impl.({distro_size = None; distro_install_info = ("Windows installer", "NetFX")}) in
+                if install = 1 && release >= release_version then `Installed
+                else `Uninstalled Impl.({distro_size = None; distro_install_info = ("Windows installer", "NetFX")}) in
               self#add_package_implementation
                 ~main:""      (* .NET executables do not need a runner on Windows but they need one elsewhere *)
                 ~package_state
@@ -710,7 +716,7 @@ module Win = struct
                   let quick_test = Some (java_bin, UnchangedSince info.Unix.st_mtime) in
                   self#add_package_implementation
                     ~main:java_bin
-                    ~package_state:`installed
+                    ~package_state:`Installed
                     ~version
                     ~machine:(Arch.parse_machine machine)
                     ~quick_test
@@ -756,7 +762,7 @@ module Win = struct
         | [], _ -> query.problem (Printf.sprintf "%s: Unknown Cygwin package" query.package_name)
         | infos, quick_test ->
         infos |> List.iter (fun (version, machine) ->
-          self#add_package_implementation ~package_state:`installed ~version ~machine ~quick_test ~distro_name query
+          self#add_package_implementation ~package_state:`Installed ~version ~machine ~quick_test ~distro_name query
         )
 
       method check_for_candidates ~ui:_ _feed = Lwt.return ()
@@ -766,11 +772,11 @@ end
 module Ports = struct
   let pkg_db = "/var/db/pkg"
 
-  let ports_distribution ?(pkg_db=pkg_db) config =
+  let ports_distribution ?(pkg_db=pkg_db) ~packagekit config =
     let re_name_version = Str.regexp "^\\(.+\\)-\\([^-]+\\)$" in
 
     object (self)
-      inherit packagekit_distro config  (* Can ports use PackageKit? Not sure. *)
+      inherit packagekit_distro ~packagekit config  (* Can ports use PackageKit? Not sure. *)
       val id_prefix = "package:ports"
       val distro_name = "Ports"
       val check_host_python = true
@@ -786,7 +792,7 @@ module Ports = struct
                 try_cleanup_distro_version_warn version query.package_name |> if_some (fun version ->
                   let (_host_os, host_machine) = Arch.platform config.system in
                   self#add_package_implementation
-                    ~package_state:`installed
+                    ~package_state:`Installed
                     ~version
                     ~machine:(Some host_machine)
                     ~quick_test:None
@@ -807,9 +813,9 @@ module Gentoo = struct
     | '0' .. '9' -> true
     | _ -> false
 
-  let gentoo_distribution ?(pkgdir=Ports.pkg_db) config =
+  let gentoo_distribution ?(pkgdir=Ports.pkg_db) ~packagekit config =
     object (self)
-      inherit packagekit_distro config as super
+      inherit packagekit_distro ~packagekit config as super
       val! valid_package_name = Str.regexp "^[^.-][^/]*/[^./][^/]*$"
       val distro_name = "Gentoo"
       val id_prefix = "package:gentoo"
@@ -848,7 +854,7 @@ module Gentoo = struct
                       ) in
                     let machine = Arch.parse_machine (Support.System.canonical_machine machine) in
                     self#add_package_implementation
-                      ~package_state:`installed
+                      ~package_state:`Installed
                       ~version
                       ~machine
                       ~quick_test:(Some (pf_path, UnchangedSince pf_mtime))
@@ -864,9 +870,9 @@ end
 module Slackware = struct
   let slack_db = "/var/log/packages"
 
-  let slack_distribution ?(packages_dir=slack_db) config =
+  let slack_distribution ?(packages_dir=slack_db) ~packagekit config =
     object (self)
-      inherit packagekit_distro config as super
+      inherit packagekit_distro ~packagekit config as super
       val distro_name = "Slack"
       val id_prefix = "package:slack"
       val check_host_python = false
@@ -880,7 +886,7 @@ module Slackware = struct
               let machine = Arch.parse_machine (Support.System.canonical_machine arch) in
               try_cleanup_distro_version_warn (version ^ "-" ^ build) query.package_name |> if_some (fun version ->
               self#add_package_implementation
-                ~package_state:`installed
+                ~package_state:`Installed
                 ~version
                 ~machine
                 ~quick_test:(Some (packages_dir +/ entry, Exists))
@@ -892,9 +898,8 @@ module Slackware = struct
     end
 end
 
-let get_host_distribution config : Distro.distribution =
+let get_host_distribution ~packagekit config : Distro.distribution =
   let exists = config.system#file_exists in
-
   match Sys.os_type with
   | "Unix" ->
       let is_debian =
@@ -903,27 +908,27 @@ let get_host_distribution config : Distro.distribution =
         | _ -> false in
 
       if is_debian then
-        Debian.debian_distribution config
+        Debian.debian_distribution ~packagekit config
       else if exists ArchLinux.arch_db then
-        ArchLinux.arch_distribution config
+        ArchLinux.arch_distribution ~packagekit config
       else if exists RPM.rpm_db_packages then
-        RPM.rpm_distribution config
+        RPM.rpm_distribution ~packagekit config
       else if exists Mac.macports_db then
         Mac.macports_distribution config
       else if exists Ports.pkg_db then (
         if config.system#platform.Platform.os = "Linux" then
-          Gentoo.gentoo_distribution config
+          Gentoo.gentoo_distribution ~packagekit config
         else
-          Ports.ports_distribution config
+          Ports.ports_distribution ~packagekit config
       ) else if exists Slackware.slack_db then
-        Slackware.slack_distribution config
+        Slackware.slack_distribution ~packagekit config
       else begin match config.system#platform.Platform.os with
       | "Darwin" | "MacOSX" ->
           Mac.darwin_distribution config
       | _unknown ->
-          generic_distribution config
+          generic_distribution ~packagekit config
       end
   | "Win32" -> Win.windows_distribution config
   | "Cygwin" -> Win.cygwin_distribution config
   | _ ->
-      generic_distribution config
+      generic_distribution ~packagekit config
