@@ -44,9 +44,9 @@ let get_download_size info impl =
 let get_fetch_info config impl =
   try
     match impl.Impl.impl_type with
-    | `binary_of _ -> ("(compile)", "Need to compile from source")
-    | `local_impl path -> ("(local)", path)
-    | `cache_impl info -> (
+    | `Binary_of _ -> ("(compile)", "Need to compile from source")
+    | `Local_impl path -> ("(local)", path)
+    | `Cache_impl info -> (
         match Stores.lookup_maybe config.system info.Impl.digests config.stores with
         | None ->
           begin match get_download_size info impl with
@@ -56,10 +56,10 @@ let get_fetch_info config impl =
           | None -> ("-", "No size") end;
         | Some path -> ("(cached)", "This version is already stored on your computer:\n" ^ path)
     )
-    | `package_impl info ->
+    | `Package_impl info ->
         begin match info.Impl.package_state with
-        | `installed -> ("(package)", "This distribution-provided package is already installed.")
-        | `uninstalled retrieval_method ->
+        | `Installed -> ("(package)", "This distribution-provided package is already installed.")
+        | `Uninstalled retrieval_method ->
           let size = retrieval_method.Impl.distro_size |> pipe_some (fun s -> Some (Int64.to_float s)) in
           match size with
           | None -> ("(install)", "No size information available for this download")
@@ -146,7 +146,7 @@ let download_icon (fetcher:Fetch.fetcher) (feed_provider:Feed_provider.feed_prov
       fetcher#download_icon parsed_url href
 
 let add_feed config iface feed_url =
-  let (`remote_feed url | `local_feed url) = feed_url in
+  let (`Remote_feed url | `Local_feed url) = feed_url in
 
   let feed = Feed_cache.get_cached_feed config feed_url |? lazy (raise_safe "Failed to read new feed!") in
   match Feed.get_feed_targets feed with
@@ -164,10 +164,10 @@ let add_feed config iface feed_url =
       );
   | feed_for -> raise_safe "This is not a feed for '%s'.\nOnly for:\n%s" iface (String.concat "\n" feed_for)
 
-let add_remote_feed config fetcher iface (feed_url:[`remote_feed of feed_url]) =
+let add_remote_feed config fetcher iface (feed_url:[`Remote_feed of Sigs.feed_url]) =
   Driver.download_and_import_feed fetcher feed_url >>= function
-  | `aborted_by_user -> Lwt.return ()
-  | `success _ | `no_update -> add_feed config iface feed_url; Lwt.return ()
+  | `Aborted_by_user -> Lwt.return ()
+  | `Success _ | `No_update -> add_feed config iface feed_url; Lwt.return ()
 
 let remove_feed config iface feed_url =
   let iface_config = Feed_cache.load_iface_config config iface in
@@ -193,22 +193,23 @@ let set_impl_stability config {Feed_url.feed; Feed_url.id} rating =
  * On error, report both stdout and stderr. *)
 let run_subprocess argv =
   log_info "Running %s" (Support.Logging.format_argv_for_logging (Array.to_list argv));
-  try_lwt
-    let command = (argv.(0), argv) in
-    let child = Lwt_process.open_process_full command in
-    Lwt_io.close child#stdin >>= fun () ->
-    let stdout = Lwt_io.read child#stdout
-    and stderr = Lwt_io.read child#stderr in
-    stdout >>= fun stdout ->
-    stderr >>= fun stderr ->
-    child#close >>= function
-    | Unix.WEXITED 0 -> Lwt.return stdout
-    | status ->
-        let output = stdout ^ stderr in
-        if output = "" then Support.System.check_exit_status status;
-        raise_safe "Compile failed: %s" output
-  with Safe_exception _ as ex ->
-    reraise_with_context ex "... executing %s" (Support.Logging.format_argv_for_logging (Array.to_list argv))
+  with_error_info
+    (fun f -> f "... executing %s" (Support.Logging.format_argv_for_logging (Array.to_list argv)))
+    (fun () ->
+      let command = (argv.(0), argv) in
+      let child = Lwt_process.open_process_full command in
+      Lwt_io.close child#stdin >>= fun () ->
+      let stdout = Lwt_io.read child#stdout
+      and stderr = Lwt_io.read child#stderr in
+      stdout >>= fun stdout ->
+      stderr >>= fun stderr ->
+      child#close >>= function
+      | Unix.WEXITED 0 -> Lwt.return stdout
+      | status ->
+          let output = stdout ^ stderr in
+          if output = "" then Support.System.check_exit_status status;
+          raise_safe "Compile failed: %s" output
+    )
 
 let build_and_register config iface min_0compile_version =
   run_subprocess [|
@@ -299,23 +300,24 @@ let get_bug_report_details config ~role (ready, results) =
   Buffer.contents b
 
 let run_test config distro test_callback (ready, results) =
-  try_lwt
-    if ready then (
-      let sels = Solver.selections results in
-      match Driver.get_unavailable_selections config ~distro sels with
-      | [] -> test_callback sels
-      | missing ->
-          let details =
-            missing |> List.map (fun sel ->
-              Printf.sprintf "%s version %s\n  (%s)"
-                (Element.interface sel)
-                (Element.version sel)
-                (Element.id sel)
-            ) |> String.concat "\n\n- " in
-          raise_safe "Can't run: the chosen versions have not been downloaded yet. I need:\n\n- %s" details
-    ) else raise_safe "Can't do a test run - solve failed"
-  with Safe_exception _ as ex ->
-    Lwt.return (Printexc.to_string ex)
+  Lwt.catch
+    (fun () ->
+      if ready then (
+        let sels = Solver.selections results in
+        match Driver.get_unavailable_selections config ~distro sels with
+        | [] -> test_callback sels
+        | missing ->
+            let details =
+              missing |> List.map (fun sel ->
+                Printf.sprintf "%s version %s\n  (%s)"
+                  (Element.interface sel)
+                  (Element.version sel)
+                  (Element.id sel)
+              ) |> String.concat "\n\n- " in
+            raise_safe "Can't run: the chosen versions have not been downloaded yet. I need:\n\n- %s" details
+      ) else raise_safe "Can't do a test run - solve failed"
+    )
+    (fun ex -> Lwt.return (Printexc.to_string ex))
 
 let try_get_gui config ~use_gui =
   let system = config.system in
@@ -421,8 +423,8 @@ let generate_feed_description config trust_db feed overrides =
   let times = ref [] in
 
   begin match feed.F.url with
-  | `local_feed _ -> Lwt.return []
-  | `remote_feed _ as feed_url ->
+  | `Local_feed _ -> Lwt.return []
+  | `Remote_feed _ as feed_url ->
       let domain = Trust.domain_from_url feed_url in
       get_sigs config feed_url >>= fun sigs ->
       if sigs <> [] then (
@@ -460,7 +462,7 @@ let generate_feed_description config trust_db feed overrides =
     | None -> ["-"] in
 
   let homepages = Element.feed_metadata feed.F.root |> U.filter_map (function
-    | `homepage homepage -> Some (Element.simple_content homepage)
+    | `Homepage homepage -> Some (Element.simple_content homepage)
     | _ -> None
   ) in
 
