@@ -4,11 +4,10 @@
 
 (** A structure representing constraints/requirements specified by the user *)
 
-open General
 open Support.Common
 
 type t = {
-  interface_uri : iface_uri;
+  interface_uri : Sigs.iface_uri;
   command : string option;
   source : bool;
   extra_restrictions : string StringMap.t;  (* iface -> range *)
