@@ -33,12 +33,11 @@ let lookup_any system digests stores =
       let str_stores = String.concat "\n- " stores in
       raise (Not_stored ("Item with digest " ^ str_digests ^ " not found in stores. Searched:\n- " ^ str_stores))
 
-let read_impl_dirs (system:system) basedirs =
+let read_impl_dirs (system:system) paths =
   (* Read the old implementation-dirs configuration file *)
   let extra_impl_dirs = ref [] in
-  let impl_dirs = "0install.net" +/ "injector" +/ "implementation-dirs" in
-  basedirs.Support.Basedir.config |> List.iter (fun dir ->
-    let path = dir +/ impl_dirs in
+  Paths.Config.(all_paths implementation_dirs) paths
+  |> List.iter (fun path ->
     try
       if system#file_exists path then (
         let re_cache_dir = Str.regexp "^\\([^#].*\\)$" in
@@ -58,10 +57,9 @@ let read_impl_dirs (system:system) basedirs =
   );
   !extra_impl_dirs
 
-let get_default_stores system basedirs =
-  let open Support.Basedir in
-  List.map (fun prefix -> prefix +/ "0install.net" +/ "implementations") basedirs.cache
-  @ read_impl_dirs system basedirs
+let get_default_stores system paths =
+  Paths.Cache.(all_paths implementations) paths
+  @ read_impl_dirs system paths
 
 let get_available_digests (system:system) stores =
   let digests = Hashtbl.create 1000 in
@@ -190,15 +188,15 @@ let add_to_store config store digest tmpdir =
 
 let add_with_helper config required_digest tmpdir =
   let system = config.system in
-  if fst required_digest = "sha1" then Lwt.return `no_helper     (* Old digest alg not supported *)
-  else if system#getenv "ZEROINSTALL_PORTABLE_BASE" <> None then Lwt.return `no_helper  (* Can't use helper with portable mode *)
+  if fst required_digest = "sha1" then Lwt.return `No_helper     (* Old digest alg not supported *)
+  else if system#getenv "ZEROINSTALL_PORTABLE_BASE" <> None then Lwt.return `No_helper  (* Can't use helper with portable mode *)
   else (
     match U.find_in_path system "0store-secure-add-helper" with
-    | None -> log_info "'0store-secure-add-helper' command not found. Not adding to system cache."; Lwt.return `no_helper
+    | None -> log_info "'0store-secure-add-helper' command not found. Not adding to system cache."; Lwt.return `No_helper
     | Some helper ->
         let digest_str = Manifest.format_digest required_digest in
         if config.dry_run then (
-          Dry_run.log "would use %s to store %s in system store" helper digest_str; Lwt.return `success
+          Dry_run.log "would use %s to store %s in system store" helper digest_str; Lwt.return `Success
         ) else (
           let env = Array.append system#environment [|
             (* (warn about insecure configurations) *)
@@ -219,10 +217,10 @@ let add_with_helper config required_digest tmpdir =
             try
               Support.System.check_exit_status status;
               log_info "Added succcessfully using helper.";
-              Lwt.return `success
+              Lwt.return `Success
             with Safe_exception _ as ex ->
               log_warning ~ex "Error running %s" helper;
-              Lwt.return `no_helper
+              Lwt.return `No_helper
           )
         )
   )
@@ -276,8 +274,8 @@ let check_manifest_and_rename config required_digest tmpdir =
         Lwt.return ()
       with Unix.Unix_error (Unix.EACCES, _, _) | Unix.Unix_error (Unix.EROFS, _, _) ->
         Lwt.bind (add_with_helper config required_digest tmpdir) (function
-          | `success -> U.rmtree config.system ~even_if_locked:true tmpdir; Lwt.return ()
-          | `no_helper -> add_to_store config user_store required_digest tmpdir; Lwt.return ()
+          | `Success -> U.rmtree config.system ~even_if_locked:true tmpdir; Lwt.return ()
+          | `No_helper -> add_to_store config user_store required_digest tmpdir; Lwt.return ()
         )
 
 (** Like [check_manifest_and_rename], but copies [dir] rather than renaming it. *)
