@@ -13,7 +13,7 @@ exception Not_stored of string
 
 val lookup_maybe : system -> Manifest.digest list -> stores -> filepath option
 val lookup_any : system -> Manifest.digest list -> stores -> string
-val get_default_stores : system -> Support.Basedir.basedirs -> stores
+val get_default_stores : system -> Paths.t -> stores
 
 (** Scan all the stores and build a set of the available digests. This can be used
     later to quickly test whether a digest is in the cache. *)
@@ -21,7 +21,7 @@ val get_available_digests : system -> stores -> available_digests
 val check_available : available_digests -> Manifest.digest list -> bool
 
 (* (for parsing <implementation> and <selection> elements) *)
-val get_digests : [< `implementation | `selection] Element.t -> Manifest.digest list
+val get_digests : [< `Implementation | `Selection] Element.t -> Manifest.digest list
 
 (* Raises an exception if no digest is supported *)
 val best_digest : Manifest.digest list -> Manifest.digest
